local LBF = LibStub("LibButtonFacade",true)
local LSM = LibStub("LibSharedMedia-3.0",true)
local AceGUI = LibStub("AceGUI-3.0",true)
local resetkeys = {"shift", "ctrl", "alt"}
function Yata:PopulateOptions()
local options = {
    name = "Yata",
    handler = Yata,
    type = 'group',
    args = {
		lock = {
			name = "Lock frames",
			desc = "Lock frames",
			type = "toggle",
			get = function() return self.db.profile.Locked end,
			set = function(info, value)
				self.db.profile.Locked = value
				if(value) then
					self:StopMoving()
				else
					self:StartMoving()
				end				
			end,
			disabled = function() return InCombatLockdown() end,
			},
		totembuttons = {
			name = "Totem buttons",
			desc = "Totem buttons configuration",
			type = "group",
			args = {
				autobuttonswap = {
					name = "Auto button-swap",
					desc = "Enable automatic button swapping",
					type = "toggle",
					get = function() return self.db.profile.AutoButtonSwap end,
					set = function(info, value) self:SetAutoButtonSwap(value) end,
					disabled = function() return InCombatLockdown() end,
				},
				buttongap = {
					name = "Button gap",
					desc = "Changes the gap between button",
					type = "range",
					get = function() return self.db.profile.ButtonGap end,
					set = function(info, value) self:SetBarConfiguration(value, self.db.profile.BarOrientation, self.db.profile.VisibleButtons) end,
					min = 0,
					max = 8,
					step = 1,
					disabled = function() return InCombatLockdown() end,
				},					
				visiblebuttons = {
					name = "Visible buttons",
					desc = "Changes the always-visible buttons",
					type = "range",
					get = function() return self.db.profile.VisibleButtons end,
					set = function(info, value) self:SetBarConfiguration(self.db.profile.ButtonGap, self.db.profile.BarOrientation, value) end,
					min = 1,
					max = 10,
					step = 1,
					disabled = function() return InCombatLockdown() end,	
				},								
			},
		},
		totembar = {
			name = "Totem bar",
			desc = "Totem bar configuration",
			type = "group",
			args = {
				barorientation = {
					name = "Bar orientation",
					desc = "Changes the bar orientation",
					type = "select",
					values = {"Horizontal, Top-Popup", "Horizontal, Bottom-Popup"},
					get = function() return self.db.profile.BarOrientation end,
					set = function(info, value) self:SetBarConfiguration(self.db.profile.ButtonGap, value, self.db.profile.VisibleButtons) end,
					disabled = function() return InCombatLockdown() end,
				},
				barscale = 	{
					name = "Bar scale",
					desc = "Changes the bar scaling",
					type = "range",
					get = function() return self.db.profile.BarScale end,
					set = function(info, value)
						self.db.profile.BarScale = value 
						self.TotemBarGrip:SetScale(self.db.profile.BarScale)
					end,
					min = 0.5,
					max = 1.5,
					step = 0.01,
					bigStep = 0.05,
					disabled = function() return InCombatLockdown() end,
				},
				totemlayout = {
					name = "Layout editor",
					desc = "Changes the layout of the totem buttons",
					type = "execute",
					func = function() local editor = AceGUI:Create("Yata_TotemButtonLayoutEditor") end,
					disabled = function() return InCombatLockdown() end,
				},
			},				
		},
		totemtimers = {
			name = "Totem timers",
			desc = "Totem timers",
			type = "group",
			args = {
				enabletimers = {
					name = "Enable timers",
					desc = "Enable timer",
					type = "toggle",
					get = function() return self.db.profile.TimerEnabled end,
					set = function(info, value) self.db.profile.TimerEnabled = value end,
					disabled = function() return InCombatLockdown() end,
				},
				timertype = {
					name = "Timer type",
					desc = "Changes the timer type",
					type = "select",
					values = {"Timer bars", "Button timer"},
					get = function() return self.db.profile.TimerType end,
					set = function(info, value) self.db.profile.TimerType = value end,
					disabled = function() return InCombatLockdown() end,
				},					
			},
		},
		totemmacro = {
			name = "Totem macro",
			desc = "Totem macro",
			type = "group",
			args = {
				resetkey = {
					name = "Macro reset key",
					desc = "Changes the macro reset key",
					type = "select",
					values = resetkeys,
					get = function() for k,v in ipairs(resetkeys) do if v == self.db.profile.MacroResetKey then return k end end end,
					set = function(info, value) local oldKey = self.db.profile.MacroResetKey self.db.profile.MacroResetKey = resetkeys[value] self:EditMacro(oldKey, self.db.profile.MacroResetKey) end,
					disabled = function() return InCombatLockdown() end,
				},
			},
		},
	},
}
if LBF then
	buttonskin = {
		name = "Button Skin",
		desc = "Sets the Button Skin",
		type = "select",
		values = function() return LBF:ListSkins() end,
		get = function() return self.db.profile.ButtonSkin  end,
		set = function(info, value) self:SetButtonSkin(value) end,
		disabled = function() return InCombatLockdown() end,
	}
	options.args.totembuttons.args["buttonskin"] = buttonskin
end
if LSM then
	timerbarskin = {
		name = "Timer bar texture",
		desc = "Changes the timer bar texture",
		type = "select",
		values = function() return LSM:List("statusbar") end,
		get = function() for k,v in ipairs(LSM:List("statusbar")) do if v == self.db.profile.TimerBarSkin then return k end end end,
		set = function(info, value) self.db.profile.TimerBarSkin = LSM:List("statusbar")[value] self:LoadTimerConfig() end,
		disabled = function() return InCombatLockdown() end,
	}
	options.args.totembar.args["timerbarskin"] = timerbarskin
end
return options
end 